//
//	名称
//		やすらかシステム ノード側
//			HDC1000ドライバ
//				温度/湿度計測モジュール
//
//	バージョン
//		0.1.1
//
//	HDC1000の設定
//		I2Cアドレス				= 0x40・・・変えられない
//		温度/湿度の変換bit数	= 14bi
//		モード					= 0で使用t

//-- インクルード --
#include <float.h>
#include <stdio.h>
#include <wiringPi.h>

//-- マクロ --
#define	I2C_ADDRESS			0x40				// I2Cアドレス

//-- 型定義 --

//-- プロトタイプ宣言 --
float	get_temperature( void);
float	get_humidity( void);

//-- グローバル変数 --

//
// 温度取得関数
//
float	get_temperature( void)	{
	int 			fd;
	unsigned char	buf[4];
	float			ret;
	
	// WiringPIを初期化
	if( (fd=wiringPiI2CSetup(I2C_ADDRESS)) < 0 )  {
		printf("wiringPiI2CSetupエラー\n");
	}
 	
	// モード0に設定
	wiringPiI2CWriteReg16(fd, 0x02, 0x0000);
	
	// 変換開始のライトアクセス
	buf[0] = 0x01;
	wiringPiI2CWriteReg8( fd, 0x00, 0x00);
	
	// 変換完了を待つ(500uSはマージン)
	usleep(6350+500);
	
	// 変換値をリードし物理値に換算
	read( fd, buf, 2);
	ret = ((buf[0] * 256 + buf[1]) * 165 / 65536.0) - 40;
	
	return(ret);
}

//
// 湿度取得関数
//
float	get_humidity( void)  {
	int 			fd;
	unsigned char	buf[4];
	float			ret;
	
	// WiringPIを初期化
	if( (fd=wiringPiI2CSetup(I2C_ADDRESS)) < 0 )  {
		printf("wiringPiI2CSetupエラー\n");
	}
 	
	// モード0に設定
	wiringPiI2CWriteReg16(fd, 0x02, 0x0000);
	
	// 変換開始のライトアクセス
	buf[0] = 0x01;
	wiringPiI2CWriteReg8( fd, 0x01, 0x00);
	
	// 変換完了を待つ(500uSはマージン)
	usleep(6500+500);
	
	// 変換値をリードし物理値に換算
	read( fd, buf, 2);
	ret = (buf[0] * 256 + buf[1]) * 100.0 / 65536.0;

	return(ret);
}
